BidiRope class

Constructors

BidiRope.empty()
factory
BidiRope.fromString(String text)
factory

Properties

containsRtl bool
no setter
hashCode int
The hash code for this object.
no setteroverride
isRtl bool
no setter
length int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

breakLines(double measureText(String), double maxWidth) List<String>
breakLinesSimple(int maxCharsPerLine) List<String>
charAt(int index) String
concat(BidiRope other) BidiRope
delete(int start, int end) BidiRope
getRtlSegments() List<List<int>>
insert(int index, String text) BidiRope
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
split(int index) → (BidiRope, BidiRope)
substring(int start, [int? end]) BidiRope
toRope() Rope
toString() String
A string representation of this object.
override
toStringWithControls() String

Operators

operator ==(Object other) bool
The equality operator.
override