LineBreaking class

Constructors

LineBreaking()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

breakBidirectionalLines(String text, List<List<int>> rtlSegments, double measureText(String), double maxWidth) List<String>
breakLines(String text, double measureText(String), double maxWidth) List<String>
findBreakOpportunities(String text) List<(int, BreakOpportunity)>