bidi_rope library
A bidirectional text-aware extension to the Rope data structure.
This library provides bidirectional text support for the existing Rope implementation, adding proper handling of mixed left-to-right (LTR) and right-to-left (RTL) text common in languages like Arabic, Hebrew, and Persian.
Classes
- BidirectionalText
- Bidirectional text contains both left-to-right (LTR) and right-to-left (RTL) writing directions, common in languages like Arabic, Hebrew, and Persian.
- BidiRope
- LineBreaking
Enums
- BidiCategory
- The Unicode Bidirectional Algorithm categories
- BreakOpportunity