BidirectionalText class
Bidirectional text contains both left-to-right (LTR) and right-to-left (RTL) writing directions, common in languages like Arabic, Hebrew, and Persian.
...........
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
containsRtl(
String text) → bool -
findFirstStrongDirectional(
String text) → int -
findRtlSegments(
String text) → List< List< int> > -
isRtl(
String text) → bool -
reorderBidirectional(
String text) → String -
wrapWithControls(
String text) → String - Applies bidirectional control characters to ensure correct display.